<?php
defined( 'ABSPATH' ) || exit;

class TMfeedCarousel  
{
    /**
	 * The single instance of the class.
	 */
	protected static $_instance = null;

    /**
	 * Main Instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

    /**
	 * TMfeedCarousel Constructor.
	 */

    public function __construct()
    {
        add_action('template_redirect', array($this, 'catch_widget_query'));
    }

    /**
	 * Get Settings.
	 */
    public function settings(){
        $post_limit = cmb2_get_option( 'tmfeed_options', 'tmf_post_limit', 10);
        $settings = array(
            'tmf_placeholder' => cmb2_get_option( 'tmfeed_options_2', 'tmf_slider_placeholder', esc_url(plugin_dir_url( __FILE__ ) . 'assets/placeholder.png')),
            'tmf_order' => get_query_var('tmf_order') ? get_query_var('tmf_order') : 'DESC',
            'tmf_orderby' => get_query_var('tmf_orderby') ? get_query_var('tmf_orderby') : 'post_date',
            'tmf_post_limit' => get_query_var('tmf_post_limit') && get_query_var('tmf_post_limit') <= $post_limit ? get_query_var('tmf_post_limit') : $post_limit,
            'tmf_date' => get_query_var('tmf_date') ? get_query_var('tmf_date') : 'date',
            'tmf_excerpt' => get_query_var('tmf_excerpt') ? get_query_var('tmf_excerpt') : 0,
            'tmf_theme' => get_query_var('tmf_theme') ? get_query_var('tmf_theme') : 'light',
            'tmf_autoplay' => get_query_var('tmf_autoplay') ? get_query_var('tmf_autoplay') : 'false',
            'tmf_interval' => get_query_var('tmf_interval') ? get_query_var('tmf_interval') : 5000,
            'tmf_direction' => is_rtl() ? 'rtl' : 'ltr',
            'tmf_font_family' => get_query_var('tmf_font_family') ? 'font-family:' . TMfeed_get_font(get_query_var('tmf_font_family')) . ';' : 'font-family:' . TMfeed_get_font(1) . ';',
            'tmf_font_size' => get_query_var('tmf_font_size') ? 'font-size:' . get_query_var('tmf_font_size') . 'px;' : 'font-size:16px;',
            'tmf_ref' => get_query_var('tmf_ref') ? get_query_var('tmf_ref') : 'iframe',
            'tmf_post_tax' => get_query_var('tmf_post_tax') ? get_query_var('tmf_post_tax') : 0
        );
        return $settings;
    }

    /**
	 * Page Output (Embeddable Content).
     * Since we're only outputting a barebones page here, there is no point to use "wp_enqueue_style, wp_enqueue_scripts, wp_head, wp_footer etc." ("template_redirect" is called quite late in the process, just before the scripts and styles are enqueued, but before wp_head).
	 */

    private function page_output(){
        $settings = $this->settings();
        ?>
        <!DOCTYPE html>
        <html <?php language_attributes(); ?> style="<?php echo esc_attr($settings['tmf_font_size']); ?>">
            <head>
                <title><?php bloginfo( 'title' ); ?></title>
                <meta charset="<?php bloginfo( 'charset' ); ?>">
                <link rel="stylesheet" media="all" href="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'css/splide.min.css'); ?>?v=1.0.0" />
                <link rel="stylesheet" media="all" href="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'css/carousel.css'); ?>?v=1.0.1" />
                <?php if (is_rtl()) { ?>
                    <link rel="stylesheet" media="all" href="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'css/carousel-rtl.css'); ?>?v=1.0.1" />
                <?php } ?>
                <?php 
                $custom_css = cmb2_get_option( 'tmfeed_options', 'tmf_custom_css', '');
                if (!empty($custom_css)) {
                    echo '<style>' . esc_attr($custom_css) . '</style>';
                }
                ?>
            </head>
            <body id="tmf-carousel-widget" class="<?php echo esc_attr($settings['tmf_theme']); ?>" style="<?php echo esc_attr($settings['tmf_font_family']); ?>">

            <?php

            /* Here we get recent posts */
            $args = array(
                'numberposts' => $settings['tmf_post_limit'],
                'offset' => 0,
                'category' => $settings['tmf_post_tax'],
                'orderby' => $settings['tmf_orderby'],
                'order' => $settings['tmf_order'],
                'post_type' => 'post',
                'post_status' => 'publish',
                'suppress_filters' => true
            );

            $recent_posts = wp_get_recent_posts($args);

            if(is_array($recent_posts)) {
            ?>
            <div id="fullscreen-slider" class="splide" data-autoplay="<?php echo esc_js($settings['tmf_autoplay']); ?>" data-interval="<?php echo esc_js($settings['tmf_interval']); ?>" data-direction="<?php echo esc_js($settings['tmf_direction']); ?>">
                <div class="splide__track">
                    <ul class="splide__list">
                        <?php foreach($recent_posts as $recent) { ?>
                        <li class="splide__slide">
                            <div class="splide__slide__container">
                                <?php if ($settings['tmf_date'] == 'date') { ?>
                                <div class="splide_date">
                                    <i class="icon-calendar"></i><?php echo esc_html(get_the_time(cmb2_get_option( 'tmfeed_options', 'tmf_date_format', 'F j, Y'), $recent["ID"])); ?>
                                </div>
                                <?php } else if($settings['tmf_date'] == 'timeago') { ?>
                                    <div class="splide_date">
                                        <i class="icon-clock"></i><?php echo esc_html(human_time_diff( get_the_time('U', $recent["ID"]), current_time('timestamp') ) . ' ' . esc_html__('ago', 'tmfeed')); ?>
                                    </div>
                                <?php } ?>
                                <?php 
                                $featured_img = $settings['tmf_placeholder'];
                                $thumb_size = cmb2_get_option( 'tmfeed_options_2', 'tmf_slider_img_size', 'large');
                                if (get_the_post_thumbnail( $recent["ID"], $thumb_size)) {
                                    $featured_id = get_post_thumbnail_id($recent["ID"]);
                                    $featured_url_array = wp_get_attachment_image_src($featured_id, $thumb_size, true);
                                    $featured_img = $featured_url_array[0];
                                }
                                ?>
                                <img src="<?php echo esc_url($featured_img); ?>" alt="<?php echo esc_attr($recent["post_title"]); ?>" />
                                <a href="<?php echo esc_url(get_permalink($recent["ID"]) . '?ref=' . $settings['tmf_ref']); ?>" target="_blank" class="splide_desc">
                                    <div class="splide_desc_inner">
                                    <h5><?php echo esc_html($recent["post_title"]); ?></h5>
                                    <?php 
                                    if ((get_the_excerpt($recent["ID"])) && ($settings['tmf_excerpt'] != 0) && isset($settings['tmf_excerpt'])) {
                                        echo '<div class="tmfeed-excerpt">' . wp_kses_post(wpautop(TMfeed_excerpt($recent["ID"], $settings['tmf_excerpt']))) . '</div>';
                                    } ?>
                                    </div>
                                </a>
                            </div>
                        </li>
                        <?php } ?>
                    </ul>
                </div>
            </div>

            <?php
            } else {
                echo '<div class="notice"><strong>' . esc_html__( 'No posts found.', 'tmfeed' ) . '</strong></div>';
            }
        
        /**
         * Since we're only outputting a barebones page here, there is no point to use "wp_enqueue_scripts".
         */
        ?>
        <script type="text/javascript" src="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'js/splide.min.js'); ?>"></script>
        </body></html>

    <?php }

    /**
     * Catches our query variable. If it’s there, we’ll stop the
     * rest of WordPress from loading and do our thing, whatever 
     * that may be.

     */
    public function catch_widget_query()
    {
        /* If no 'embed' parameter found, return */
        if(!get_query_var('tmf_embed')) return;

        /* 'embed' variable is set, export the content */

        if(get_query_var('tmf_embed') == 'slider')
        {
            $this->page_output();
            exit();
        }

        
    }
}
/**
 * Returns the main instance of TMfeedCarousel.
 */
function TMfeedCarousel() {  
	return TMfeedCarousel::instance();
}
// Global for backwards compatibility.
$GLOBALS['TMfeedCarousel'] = TMfeedCarousel();