<?php
defined( 'ABSPATH' ) || exit;

class TMfeedList  
{
    /**
	 * The single instance of the class.
	 */
	protected static $_instance = null;

    /**
	 * Main Instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

    /**
	 * TMfeedList Constructor.
	 */

    public function __construct()
    {
        add_action('template_redirect', array($this, 'catch_widget_query'));
    }

    /**
	 * Get Settings.
	 */
    public function settings(){
        $post_limit = cmb2_get_option( 'tmfeed_options', 'tmf_post_limit', 10);
        $settings = array(
            'tmf_logo' => cmb2_get_option( 'tmfeed_options_1', 'tmf_logo_list', ''),
            'tmf_logo_width' => 'width:' . cmb2_get_option( 'tmfeed_options_1', 'tmf_logo_list_width', 60) . 'px;',
            'tmf_logo_url' => cmb2_get_option( 'tmfeed_options_1', 'tmf_dest_list_url', '#'),
            'tmf_thumb_style' => cmb2_get_option( 'tmfeed_options_1', 'tmf_list_thumb_style', 'circle'),
            'tmf_title' => get_query_var('tmf_title') ? get_query_var('tmf_title') : '',
            'tmf_order' => get_query_var('tmf_order') ? get_query_var('tmf_order') : 'DESC',
            'tmf_orderby' => get_query_var('tmf_orderby') ? get_query_var('tmf_orderby') : 'post_date',
            'tmf_post_limit' => get_query_var('tmf_post_limit') && get_query_var('tmf_post_limit') <= $post_limit ? get_query_var('tmf_post_limit') : $post_limit,
            'tmf_font_family' => get_query_var('tmf_font_family') ? 'font-family:' . TMfeed_get_font(get_query_var('tmf_font_family')) . ';' : 'font-family:' . TMfeed_get_font(1) . ';',
            'tmf_font_size' => get_query_var('tmf_font_size') ? 'font-size:' . get_query_var('tmf_font_size') . 'px;' : 'font-size:16px;',
            'tmf_background' => get_query_var('tmf_background') ? 'background:#' . get_query_var('tmf_background') . ';' : 'background:#ffffff;',
            'tmf_header_background' => get_query_var('tmf_header_background') ? 'background:#' . get_query_var('tmf_header_background') . ';' : 'background:#000000;',
            'tmf_header_color' => get_query_var('tmf_header_color') ? 'color:#' . get_query_var('tmf_header_color') . ';' : 'color:#ffffff;',
            'tmf_border_color' => get_query_var('tmf_border_color') ? 'border-color:#' . get_query_var('tmf_border_color') . ';' : 'border-color:#DDDDDD;',
            'tmf_link_color' => get_query_var('tmf_link_color') ? 'color:#' . get_query_var('tmf_link_color') . ';' : 'color:#000000;',
            'tmf_text_color' => get_query_var('tmf_text_color') ? 'color:#' . get_query_var('tmf_text_color') . ';' : 'color:#444444;',
            'tmf_ref' => get_query_var('tmf_ref') ? get_query_var('tmf_ref') : 'iframe',
            'tmf_post_tax' => get_query_var('tmf_post_tax') ? get_query_var('tmf_post_tax') : 0,
            'tmf_divider' => get_query_var('tmf_date') && get_query_var('tmf_author') && (get_query_var('tmf_date') != 'hide') && (get_query_var('tmf_author') == 'on') ? esc_html__( ' - ', 'tmfeed' ) : '',
            'tmf_date' => get_query_var('tmf_date') ? get_query_var('tmf_date') : 'timeago',
            'tmf_author' => get_query_var('tmf_author') ? get_query_var('tmf_author') : 'on',
            'tmf_thumb' => get_query_var('tmf_thumb') ? get_query_var('tmf_thumb') : 'on'
        );
        return $settings;
    }

    /**
	 * Page Output (Embeddable Content).
     * Since we're only outputting a barebones page here, there is no point to use "wp_enqueue_style, wp_enqueue_scripts, wp_head, wp_footer etc." ("template_redirect" is called quite late in the process, just before the scripts and styles are enqueued, but before wp_head).
	 */

    private function page_output(){
        $settings = $this->settings();
        ?>
        <!DOCTYPE html>
        <html <?php language_attributes(); ?> style="<?php echo esc_attr($settings['tmf_font_size']); ?>">
            <head>
                <title><?php bloginfo( 'title' ); ?></title>
                <meta charset="<?php bloginfo( 'charset' ); ?>">
                <link rel="stylesheet" media="all" href="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'css/list.css'); ?>?v=1.0" />
                <?php if (is_rtl()) { ?>
                    <link rel="stylesheet" media="all" href="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'css/list-rtl.css'); ?>?v=1.0" />
                <?php } ?>
                <?php 
                $custom_css = cmb2_get_option( 'tmfeed_options', 'tmf_custom_css', '');
                if (!empty($custom_css)) {
                    echo '<style>' . esc_attr($custom_css) . '</style>';
                }
                ?>
            </head>
            <body id="tmf-post-list-widget" style="<?php echo esc_attr($settings['tmf_font_family'] . $settings['tmf_background'] . $settings['tmf_text_color']); ?>">

        <?php

        /* Here we get recent posts */
        $args = array(
            'numberposts' => $settings['tmf_post_limit'],
            'offset' => 0,
            'category' => $settings['tmf_post_tax'],
            'orderby' => $settings['tmf_orderby'],
            'order' => $settings['tmf_order'],
            'post_type' => 'post',
            'post_status' => 'publish',
            'suppress_filters' => true
        );

        $recent_posts = wp_get_recent_posts($args);

        $outstring = '<div id="widget-posts" style="' . esc_attr($settings['tmf_border_color']) . '">';

        $logo = '';
        if(!empty($settings['tmf_logo'])) {
            $logo = '<img src="' . esc_url($settings['tmf_logo']) . '" alt="' . esc_attr($settings['tmf_title']) . '" style="' . esc_attr($settings['tmf_logo_width']) . '" />';
        }

        if($settings['tmf_title'] || !empty($logo)) {
            $outstring .= '<h5><a href="' . esc_url($settings['tmf_logo_url']) . '" target="_blank" style="' . esc_attr($settings['tmf_header_color'] . $settings['tmf_header_background']) . '">' . esc_html($settings['tmf_title']) . $logo . '</a></h5>';
        }
        $outstring .= '<ul>';

        if(is_array($recent_posts)) {
            foreach($recent_posts as $recent) {

                $date = '';
                if($settings['tmf_date'] == 'timeago') {
                    $date = human_time_diff( get_the_time('U', $recent["ID"]), current_time('timestamp') ) . ' ' . esc_html__('ago', 'tmfeed');
                } else if($settings['tmf_date'] == 'date') {
                    $date = get_the_time(cmb2_get_option( 'tmfeed_options', 'tmf_date_format', 'F j, Y'), $recent["ID"]);
                }

                $author = '';
                if($settings['tmf_author'] == 'on') {
                    $author = get_the_author_meta( 'display_name', $recent["post_author"] );
                }

                $outstring .= '<li style="' . esc_attr($settings['tmf_border_color']) . '">';
                if ($settings['tmf_thumb'] == 'on' && get_the_post_thumbnail( $recent["ID"], 'thumbnail')) {
                    $outstring .= '<div class="thumb ' . esc_attr($settings['tmf_thumb_style']) . '"><a target="_blank" href="' . esc_url(get_permalink($recent["ID"])) . '">' . get_the_post_thumbnail( $recent["ID"], 'thumbnail') . '</a></div>';
                }
                $outstring .= '<div class="content">';
                $outstring .= '<div><a target="_blank" style="' . esc_attr($settings['tmf_link_color']) . '" href="' . esc_url(get_permalink($recent["ID"]) . '?ref=' . $settings['tmf_ref']) . '">' . esc_html($recent["post_title"]) . '</a></div>';
                if (($settings['tmf_date'] != 'none') || ($settings['tmf_author'] == '1')) {
                    $outstring .= '<div class="date">' . $date . $settings['tmf_divider'] . $author . '</div>';
                }
                $outstring .= '</div>';
                $outstring .= '</li>';
            }
        } else {
            $outstring .= '<li><strong>' . esc_html__( 'No posts found.', 'tmfeed' ) . '</strong></li>';
        }

        $outstring .= '</ul></div>';

        echo wp_kses_post($outstring); ?>
        </body></html>


    <?php }

    /**
     * Catches our query variable. If it’s there, we’ll stop the
     * rest of WordPress from loading and do our thing, whatever 
     * that may be.

     */
    public function catch_widget_query()
    {
        /* If no 'embed' parameter found, return */
        if(!get_query_var('tmf_embed')) return;

        /* 'embed' variable is set, export the content */

        if(get_query_var('tmf_embed') == 'post_list')
        { 
            $this->page_output();
            exit();
        }

    }
}

/**
 * Returns the main instance of TMfeedList.
 */
function TMfeedList() {  
	return TMfeedList::instance();
}
// Global for backwards compatibility.
$GLOBALS['TMfeedList'] = TMfeedList();