<?php
defined( 'ABSPATH' ) || exit;

class TMfeedNewsTicker  
{
    /**
	 * The single instance of the class.
	 */
	protected static $_instance = null;

    /**
	 * Main Instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

    /**
	 * TMfeedNewsTicker Constructor.
	 */

    public function __construct()
    {
        add_action('template_redirect', array($this, 'catch_widget_query'));
    }

    /**
	 * Get Settings.
	 */
    public function settings(){
        $post_limit = cmb2_get_option( 'tmfeed_options', 'tmf_post_limit', 10);
        $settings = array(
            'tmf_title' => get_query_var('tmf_title') ? get_query_var('tmf_title') : '',
            'tmf_order' => get_query_var('tmf_order') ? get_query_var('tmf_order') : 'DESC',
            'tmf_orderby' => get_query_var('tmf_orderby') ? get_query_var('tmf_orderby') : 'post_date',
            'tmf_post_limit' => get_query_var('tmf_post_limit') && get_query_var('tmf_post_limit') <= $post_limit ? get_query_var('tmf_post_limit') : $post_limit,
            'tmf_date' => get_query_var('tmf_date') ? get_query_var('tmf_date') : 'date',
            'tmf_interval' => get_query_var('tmf_interval') ? get_query_var('tmf_interval') : 0.5,
            'tmf_direction' => is_rtl() ? 'true' : '',
            'tmf_font_family' => get_query_var('tmf_font_family') ? 'font-family:' . TMfeed_get_font(get_query_var('tmf_font_family')) . ';' : 'font-family:' . TMfeed_get_font(1) . ';',
            'tmf_font_size' => get_query_var('tmf_font_size') ? 'font-size:' . get_query_var('tmf_font_size') . 'px;' : 'font-size:15px;',
            'tmf_background' => get_query_var('tmf_background') ? 'background:#' . get_query_var('tmf_background') . ';' : 'background:#000000;',
            'tmf_header_background' => get_query_var('tmf_header_background') ? 'background:#' . get_query_var('tmf_header_background') . ';' : 'background:#cc0000;',
            'tmf_header_color' => get_query_var('tmf_header_color') ? 'color:#' . get_query_var('tmf_header_color') . ';' : 'color:#ffffff;',
            'tmf_border_color' => get_query_var('tmf_border_color') ? 'border-color:#' . get_query_var('tmf_border_color') . ';' : 'border-color:#333333;',
            'tmf_link_color' => get_query_var('tmf_link_color') ? 'color:#' . get_query_var('tmf_link_color') . ';' : 'color:#ffffff;',
            'tmf_ref' => get_query_var('tmf_ref') ? get_query_var('tmf_ref') : 'iframe',
            'tmf_post_tax' => get_query_var('tmf_post_tax') ? get_query_var('tmf_post_tax') : 0
        );
        return $settings;
    }

    /**
	 * Page Output (Embeddable Content).
     * Since we're only outputting a barebones page here, there is no point to use "wp_enqueue_style, wp_enqueue_scripts, wp_head, wp_footer etc." ("template_redirect" is called quite late in the process, just before the scripts and styles are enqueued, but before wp_head).
	 */

    private function page_output(){
        $settings = $this->settings();
        ?>
        <!DOCTYPE html>
        <html <?php language_attributes(); ?> style="<?php echo esc_attr($settings['tmf_font_size']); ?>">
            <head>
                <title><?php bloginfo( 'title' ); ?></title>
                <meta charset="<?php bloginfo( 'charset' ); ?>">
                <link rel="stylesheet" media="all" href="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'css/newsticker.css'); ?>?v=1.0" />
                <?php if (is_rtl()) { ?>
                    <link rel="stylesheet" media="all" href="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'css/newsticker-rtl.css'); ?>?v=1.0" />
                <?php } ?>
                <?php
                $custom_css = cmb2_get_option( 'tmfeed_options', 'tmf_custom_css', '');
                if (!empty($custom_css)) {
                    echo '<style>' . esc_attr($custom_css) . '</style>';
                }
                ?>
            </head>
            <body id="tmf-newsticker-widget" style="<?php echo esc_attr($settings['tmf_font_family']); ?>">

            <?php

            /* Here we get recent posts */
            $args = array(
                'numberposts' => $settings['tmf_post_limit'],
                'offset' => 0,
                'category' => $settings['tmf_post_tax'],
                'orderby' => $settings['tmf_orderby'],
                'order' => $settings['tmf_order'],
                'post_type' => 'post',
                'post_status' => 'publish',
                'suppress_filters' => true
            );

            $recent_posts = wp_get_recent_posts($args);

            if(is_array($recent_posts)) {
            ?>
            <div class="tmf-newsticker-wrapper" style="<?php echo esc_attr($settings['tmf_background']); ?>">
            <?php if (!empty($settings['tmf_title'])) { ?>
                <div class="tmf-newsticker-title" style="<?php echo esc_attr($settings['tmf_header_color'] . $settings['tmf_header_background']); ?>"><div><?php echo esc_html($settings['tmf_title']); ?></div></div>
            <?php } ?>
                <div class="tmf-newsticker-content">
                <div>
                    <div class="marquee3k" data-speed="<?php echo esc_js($settings['tmf_interval']); ?>" data-reverse="<?php echo esc_js($settings['tmf_direction']); ?>" data-pausable="true">
                        <div class="marquee3k-item">
                            <?php foreach($recent_posts as $recent) { ?>
                            <a href="<?php echo esc_url(get_permalink($recent["ID"]) . '?ref=' . $settings['tmf_ref']); ?>" target="_blank" style="<?php echo esc_attr($settings['tmf_border_color'] . $settings['tmf_link_color']); ?>">
                                <?php echo esc_html($recent["post_title"]); ?>
                            </a>
                            <?php } ?>
                        </div>
                    </div>
                    </div>
                </div>
            </div>
            <?php
            } else {
                echo '<div class="notice"><strong>' . esc_html__( 'No posts found.', 'tmfeed' ) . '</strong></div>';
            }
        
        /**
         * Since we're only outputting a barebones page here, there is no point to use "wp_enqueue_scripts".
         */
        ?>
        <script src="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'js/marquee3k.min.js'); ?>"></script>
        </body></html>

    <?php }

    /**
     * Catches our query variable. If it’s there, we’ll stop the
     * rest of WordPress from loading and do our thing, whatever 
     * that may be.

     */
    public function catch_widget_query()
    {
        /* If no 'embed' parameter found, return */
        if(!get_query_var('tmf_embed')) return;

        /* 'embed' variable is set, export the content */

        if(get_query_var('tmf_embed') == 'newsticker')
        {
            $this->page_output();
            exit();
        }

        
    }
}
/**
 * Returns the main instance of TMfeedNewsTicker.
 */
function TMfeedNewsTicker() {  
	return TMfeedNewsTicker::instance();
}
// Global for backwards compatibility.
$GLOBALS['TMfeedNewsTicker'] = TMfeedNewsTicker();