<?php
defined( 'ABSPATH' ) || exit;

class TMfeedWooSlider  
{
    /**
	 * The single instance of the class.
	 */
	protected static $_instance = null;

    /**
	 * Main Instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

    /**
	 * TMfeedWooSlider Constructor.
	 */

    public function __construct()
    {
        add_action('template_redirect', array($this, 'catch_widget_query'));
    }

    /**
	 * Get Settings.
	 */
    public function settings(){
        $post_limit = cmb2_get_option( 'tmfeed_options', 'tmf_post_limit', 10);
        $settings = array(
            'tmf_placeholder' => cmb2_get_option( 'tmfeed_options_2', 'tmf_product_slider_placeholder', esc_url(plugin_dir_url( __FILE__ ) . 'assets/placeholder.png')),
            'tmf_order' => get_query_var('tmf_order') ? get_query_var('tmf_order') : 'DESC',
            'tmf_orderby' => get_query_var('tmf_orderby') ? get_query_var('tmf_orderby') : 'post_date',
            'tmf_post_limit' => get_query_var('tmf_post_limit') && get_query_var('tmf_post_limit') <= $post_limit ? get_query_var('tmf_post_limit') : $post_limit,
            'tmf_date' => get_query_var('tmf_date') ? get_query_var('tmf_date') : 'date',
            'tmf_theme' => get_query_var('tmf_theme') ? get_query_var('tmf_theme') : 'light',
            'tmf_autoplay' => get_query_var('tmf_autoplay') ? get_query_var('tmf_autoplay') : 'false',
            'tmf_interval' => get_query_var('tmf_interval') ? get_query_var('tmf_interval') : 5000,
            'tmf_direction' => is_rtl() ? 'rtl' : 'ltr',
            'tmf_font_family' => get_query_var('tmf_font_family') ? 'font-family:' . TMfeed_get_font(get_query_var('tmf_font_family')) . ';' : 'font-family:' . TMfeed_get_font(1) . ';',
            'tmf_font_size' => get_query_var('tmf_font_size') ? 'font-size:' . get_query_var('tmf_font_size') . 'px;' : 'font-size:16px;',
            'tmf_ref' => get_query_var('tmf_ref') ? get_query_var('tmf_ref') : 'iframe',
            'tmf_post_tax' => get_query_var('tmf_post_tax') ? get_query_var('tmf_post_tax') : 0
        );
        return $settings;
    }

    /**
	 * Page Output (Embeddable Content).
     * Since we're only outputting a barebones page here, there is no point to use "wp_enqueue_style, wp_enqueue_scripts, wp_head, wp_footer etc." ("template_redirect" is called quite late in the process, just before the scripts and styles are enqueued, but before wp_head).
	 */

    private function page_output(){
        $settings = $this->settings();
        ?>
        <!DOCTYPE html>
        <html <?php language_attributes(); ?> style="<?php echo esc_attr($settings['tmf_font_size']); ?>">
            <head>
                <title><?php bloginfo( 'title' ); ?></title>
                <meta charset="<?php bloginfo( 'charset' ); ?>">
                <link rel="stylesheet" media="all" href="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'css/splide.min.css'); ?>?v=1.0.0" />
                <link rel="stylesheet" media="all" href="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'css/carousel.css'); ?>?v=1.0.1" />
                <?php if (is_rtl()) { ?>
                    <link rel="stylesheet" media="all" href="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'css/carousel-rtl.css'); ?>?v=1.0.1" />
                <?php } ?>
                <?php 
                $custom_css = cmb2_get_option( 'tmfeed_options', 'tmf_custom_css', '');
                if (!empty($custom_css)) {
                    echo '<style>' . esc_attr($custom_css) . '</style>';
                }
                ?>
            </head>
            <body id="tmf-carousel-widget" class="woocommerce <?php echo esc_attr($settings['tmf_theme']); ?>" style="<?php echo esc_attr($settings['tmf_font_family']); ?>">
            <?php

            /* Here we get recent products */

            $order_array = array();

            if ($settings['tmf_orderby'] == 'popularity') {
                $order_array = array(
                    'orderby' => 'meta_value_num',
                    'meta_key' => 'total_sales',
                    'meta_value_num' => $settings['tmf_order'],
                );
            } elseif ($settings['tmf_orderby'] == 'rating') {
                $order_array = array(
                    'orderby' => 'meta_value_num',
                    'meta_key' => '_wc_average_rating',
                    'meta_value_num' => $settings['tmf_order'],
                );
            } else {
                $order_array = array(
                    'order' => $settings['tmf_order'],
                    'orderby' => $settings['tmf_orderby']
                );
            }

            if ($settings['tmf_post_tax'] != 0) {
                $args = array(
                    'numberposts' => $settings['tmf_post_limit'],
                    'offset' => 0,
                    'post_type' => 'product',
                    'post_status' => 'publish',
                    'suppress_filters' => true,
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'term_id',
                            'terms'    => $settings['tmf_post_tax']
                        )
                    )
                );
            } else {
                $args = array(
                    'numberposts' => $settings['tmf_post_limit'],
                    'offset' => 0,
                    'post_type' => 'product',
                    'post_status' => 'publish',
                    'suppress_filters' => true
                );
            }

            $recent_posts = new WP_Query($args + $order_array);

            if ($recent_posts->have_posts()) {
                
            ?>
            <div id="fullscreen-slider" class="splide products" data-autoplay="<?php echo esc_js($settings['tmf_autoplay']); ?>" data-interval="<?php echo esc_js($settings['tmf_interval']); ?>" data-direction="<?php echo esc_js($settings['tmf_direction']); ?>">
                <div class="splide__track">
                    <ul class="splide__list">
                        <?php while($recent_posts->have_posts()) : $recent_posts->the_post();
                            global $product;
                            $featured_img = $settings['tmf_placeholder'];
                            $price = $product->get_price();
                            $price_string = wc_price($price);
                            $thumb_size = cmb2_get_option( 'tmfeed_options_2', 'tmf_product_slider_img_size', 'large');
                        ?>
                        <li class="splide__slide">
                            <div class="splide__slide__container">
                                <?php if ( $product->is_on_sale() )  { ?>
                                    <div class="product-sale"><i class="icon-tag"></i></div>
                                <?php } ?>
                                <?php if ($settings['tmf_date'] == 'price') { ?>
                                <div class="splide_date">
                                    <?php echo wp_kses_post($price_string); ?>
                                </div>
                                <?php } ?>
                                <?php
                                if (get_the_post_thumbnail( get_the_ID(), $thumb_size)) {
                                    $featured_id = get_post_thumbnail_id();
                                    $featured_url_array = wp_get_attachment_image_src($featured_id, $thumb_size, true);
                                    $featured_img = $featured_url_array[0];
                                }
                                ?>
                                <img src="<?php echo esc_url($featured_img); ?>" alt="<?php echo esc_attr(get_the_title()); ?>" />
                                <a href="<?php echo esc_url(get_permalink() . '?ref=' . $settings['tmf_ref']); ?>" target="_blank" class="splide_desc">
                                    <div class="splide_desc_inner">
                                    <h5><?php the_title(); ?></h5>
                                    </div>
                                </a>
                            </div>
                        </li>
                        <?php endwhile; ?>
                    </ul>
                </div>
            </div>

            <?php
            wp_reset_postdata();
            } else {
                echo '<div class="notice"><strong>' . esc_html__( 'No posts found.', 'tmfeed' ) . '</strong></div>';
            }
        
        /**
         * Since we're only outputting a barebones page here, there is no point to use "wp_enqueue_scripts".
         */
        ?>
        <script type="text/javascript" src="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'js/splide.min.js'); ?>"></script>
        </body></html>

    <?php }

    /**
     * Catches our query variable. If it’s there, we’ll stop the
     * rest of WordPress from loading and do our thing, whatever 
     * that may be.

     */
    public function catch_widget_query()
    {
        /* If no 'embed' parameter found, return */
        if(!get_query_var('tmf_embed')) return;

        /* 'embed' variable is set, export the content */

        if(get_query_var('tmf_embed') == 'wooslider')
        {
            $this->page_output();
            exit();
        }

        
    }
}
/**
 * Returns the main instance of TMfeedWooSlider.
 */
function TMfeedWooSlider() {  
	return TMfeedWooSlider::instance();
}
// Global for backwards compatibility.
$GLOBALS['TMfeedWooSlider'] = TMfeedWooSlider();