<?php
/**
* Hook in and register a metabox to handle a theme options page and adds a menu item.
*/
function tmfeed_register_main_options_metabox() {

/**
 * Registers main options page menu item and form.
 */
$args = array(
    'id'           => 'tmfeed_options',
    'title'        => esc_html('TMfeed Settings', 'tmfeed'),
    'object_types' => array( 'options-page' ),
    'option_key'   => 'tmfeed_options',
    'tab_group'    => 'tmfeed_options',
    'tab_title'    => esc_html('General', 'tmfeed')
);

// 'tab_group' property is supported in > 2.4.0.
if ( version_compare( CMB2_VERSION, '2.4.0' ) ) {
    $args['display_cb'] = 'tmfeed_options_display_with_tabs';
}

$main_options = new_cmb2_box( $args );

/**
 * Options fields ids only need
 * to be unique within this box.
 * Prefix is not needed.
 */

$main_options->add_field( array(
	'name' => esc_html__( 'Date Format', 'tmfeed' ),
    'desc' => esc_html__( 'https://wordpress.org/support/article/formatting-date-and-time/', 'tmfeed' ),
	'id'   => 'tmf_date_format',
	'type' => 'text',
    'default' => 'F j, Y',
) );

$main_options->add_field( array(
	'name' => esc_html__( 'Post Limit', 'tmfeed' ),
    'desc' => esc_html__( 'Maximum number of posts that can be displayed.', 'tmfeed' ),
	'id'   => 'tmf_post_limit',
	'type' => 'text',
	'attributes' => array(
		'type' => 'number',
		'pattern' => '\d*',
    ),
    'default' => 20,
) );

$main_options->add_field( array(
	'name' => esc_html__( 'Custom CSS', 'tmfeed' ),
	'id' => 'tmf_custom_css',
	'type' => 'textarea_code',
    'attributes' => array(
		'data-codeeditor' => json_encode( array(
			'codemirror' => array(
				'mode' => 'css'
			),
		) ),
	),
) );

/**
 * Registers new options page, and set main item as parent.
 */
$args = array(
    'id'           => 'tmfeed_options_1',
    'title'        => esc_html('TMfeed Settings', 'tmfeed'),
    'menu_title'   => esc_html('List', 'tmfeed'),
    'object_types' => array( 'options-page' ),
    'option_key'   => 'tmfeed_options_1',
    'parent_slug'  => 'tmfeed_options',
    'tab_group'    => 'tmfeed_options',
    'tab_title'    => esc_html('List', 'tmfeed'),
);

// 'tab_group' property is supported in > 2.4.0.
if ( version_compare( CMB2_VERSION, '2.4.0' ) ) {
    $args['display_cb'] = 'tmfeed_options_display_with_tabs';
}

$options_1 = new_cmb2_box( $args );

$options_1->add_field( array(
    'name'    => esc_html('Logo', 'tmfeed'),
	'id'      => 'tmf_logo_list',
	'type'    => 'file',
	'text'    => array(
		'add_upload_file_text' => esc_html('Upload Image', 'tmfeed'),
	),
	// query_args are passed to wp.media's library query.
	'query_args' => array(
		'type' => array(
            'image/gif',
            'image/jpeg',
            'image/png',
            'image/jpg',
		),
	),
	'preview_size' => 'medium', // Image size to use when previewing in the admin.
) );

$options_1->add_field( array(
	'name' => esc_html__( 'Logo Width', 'tmfeed' ),
	'id'   => 'tmf_logo_list_width',
	'type' => 'text',
	'attributes' => array(
		'type' => 'number',
		'pattern' => '\d*',
    ),
    'default' => 60,
) );

$options_1->add_field( array(
	'name' => esc_html__( 'Logo Link', 'tmfeed' ),
    'desc' => esc_html__( 'For example: https://codecanyon.net/', 'tmfeed' ),
	'id'   => 'tmf_dest_list_url',
	'type' => 'text_url',
    'default' => '#',
) );

$options_1->add_field( array(
	'name'             => esc_html('Thumbnail Style', 'tmfeed'),
	'id'               => 'tmf_list_thumb_style',
	'type'             => 'select',
	'show_option_none' => false,
	'default'          => 'circle',
	'options'          => array(
		'circle' => esc_html__( 'Circle', 'tmfeed' ),
        'rounded' => esc_html__( 'Rounded', 'tmfeed' ),
        'square' => esc_html__( 'Square', 'tmfeed' ),
	),
) );

/**
 * Registers new options page, and set main item as parent.
 */
$args = array(
    'id'           => 'tmfeed_options_2',
    'title'        => esc_html('TMfeed Settings', 'tmfeed'),
    'menu_title'   => esc_html('Slider', 'tmfeed'),
    'object_types' => array( 'options-page' ),
    'option_key'   => 'tmfeed_options_2',
    'parent_slug'  => 'tmfeed_options',
    'tab_group'    => 'tmfeed_options',
    'tab_title'    => esc_html('Slider', 'tmfeed'),
);

// 'tab_group' property is supported in > 2.4.0.
if ( version_compare( CMB2_VERSION, '2.4.0' ) ) {
    $args['display_cb'] = 'tmfeed_options_display_with_tabs';
}

$options_2 = new_cmb2_box( $args );

$options_2->add_field( array(
	'name'             => esc_html('Image Size', 'tmfeed'),
	'id'               => 'tmf_slider_img_size',
	'type'             => 'select',
	'show_option_none' => false,
	'default'          => 'large',
	'options'          => TMfeed_get_image_sizes()
) );

$options_2->add_field( array(
	'name'             => esc_html('Product Image Size', 'tmfeed'),
	'id'               => 'tmf_product_slider_img_size',
	'type'             => 'select',
	'show_option_none' => false,
	'default'          => 'large',
	'options'          => TMfeed_get_image_sizes()
) );

$options_2->add_field( array(
    'name'    => esc_html('Default Featured Image', 'tmfeed'),
    'desc' => esc_html__( 'Slider uses featured images of your posts. If a post has no featured image, this image will displayed.', 'tmfeed' ),
	'id'      => 'tmf_slider_placeholder',
	'type'    => 'file',
    'default' => esc_url(plugin_dir_url( __FILE__ ) . 'assets/placeholder.png'),
	'text'    => array(
		'add_upload_file_text' => esc_html('Upload Image', 'tmfeed'),
	),
	// query_args are passed to wp.media's library query.
	'query_args' => array(
		'type' => array(
            'image/gif',
            'image/jpeg',
            'image/png',
            'image/jpg',
		),
	),
	'preview_size' => 'medium', // Image size to use when previewing in the admin.
) );

$options_2->add_field( array(
    'name'    => esc_html('Default Product Image', 'tmfeed'),
    'desc' => esc_html__( 'Slider uses product images of your products. If a product has no image, this image will displayed.', 'tmfeed' ),
	'id'      => 'tmf_product_slider_placeholder',
	'type'    => 'file',
    'default' => esc_url(plugin_dir_url( __FILE__ ) . 'assets/placeholder.png'),
	'text'    => array(
		'add_upload_file_text' => esc_html('Upload Image', 'tmfeed'),
	),
	// query_args are passed to wp.media's library query.
	'query_args' => array(
		'type' => array(
            'image/gif',
            'image/jpeg',
            'image/png',
            'image/jpg',
		),
	),
	'preview_size' => 'medium', // Image size to use when previewing in the admin.
) );

/**
 * Registers new options page, and set main item as parent.
 */
$args = array(
    'id'           => 'tmfeed_options_3',
    'title'        => esc_html('TMfeed Settings', 'tmfeed'),
    'menu_title'   => esc_html('News Ticker', 'tmfeed'),
    'object_types' => array( 'options-page' ),
    'option_key'   => 'tmfeed_options_3',
    'parent_slug'  => 'tmfeed_options',
    'tab_group'    => 'tmfeed_options',
    'tab_title'    => esc_html('News Ticker', 'tmfeed'),
);

// 'tab_group' property is supported in > 2.4.0.
if ( version_compare( CMB2_VERSION, '2.4.0' ) ) {
    $args['display_cb'] = 'tmfeed_options_display_with_tabs';
}

$options_3 = new_cmb2_box( $args );

$options_3->add_field( array(
	'name' => esc_html__( 'News Ticker Height', 'tmfeed' ),
	'id'   => 'tmf_newsticker_height',
	'type' => 'text',
	'attributes' => array(
		'type' => 'number',
		'pattern' => '\d*',
    ),
    'default' => 50,
) );

}
add_action( 'cmb2_admin_init', 'tmfeed_register_main_options_metabox' );

/**
* A CMB2 options-page display callback override which adds tab navigation among
* CMB2 options pages which share this same display callback.
*
* @param CMB2_Options_Hookup $cmb_options The CMB2_Options_Hookup object.
*/
function tmfeed_options_display_with_tabs( $cmb_options ) {
$tabs = tmfeed_options_page_tabs( $cmb_options );
?>
<div class="wrap cmb2-options-page option-<?php echo esc_attr($cmb_options->option_key); ?>">
    <?php if ( get_admin_page_title() ) : ?>
        <h2><?php echo wp_kses_post( get_admin_page_title() ); ?></h2>
    <?php endif; ?>
    <h2 class="nav-tab-wrapper">
        <?php foreach ( $tabs as $option_key => $tab_title ) : ?>
            <a class="nav-tab<?php if ( isset( $_GET['page'] ) && $option_key === $_GET['page'] ) : ?> nav-tab-active<?php endif; ?>" href="<?php menu_page_url( $option_key ); ?>"><?php echo wp_kses_post( $tab_title ); ?></a>
        <?php endforeach; ?>
    </h2>
    <form class="cmb-form" action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>" method="POST" id="<?php echo esc_attr($cmb_options->cmb->cmb_id); ?>" enctype="multipart/form-data" encoding="multipart/form-data">
        <input type="hidden" name="action" value="<?php echo esc_attr( $cmb_options->option_key ); ?>">
        <?php $cmb_options->options_page_metabox(); ?>
        <?php submit_button( esc_attr( $cmb_options->cmb->prop( 'save_button' ) ), 'primary', 'submit-cmb' ); ?>
    </form>
</div>
<?php
}

/**
* Gets navigation tabs array for CMB2 options pages which share the given
* display_cb param.
*
* @param CMB2_Options_Hookup $cmb_options The CMB2_Options_Hookup object.
*
* @return array Array of tab information.
*/
function tmfeed_options_page_tabs( $cmb_options ) {
$tab_group = $cmb_options->cmb->prop( 'tab_group' );
$tabs      = array();

foreach ( CMB2_Boxes::get_all() as $cmb_id => $cmb ) {
    if ( $tab_group === $cmb->prop( 'tab_group' ) ) {
        $tabs[ $cmb->options_page_keys()[0] ] = $cmb->prop( 'tab_title' )
            ? $cmb->prop( 'tab_title' )
            : $cmb->prop( 'title' );
    }
}

return $tabs;
}
