<?php
namespace ElementorTMfeed;

class TMfeedLoadElementor {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function widget_styles() {
		wp_register_style( 'spectrum', plugins_url( '/css/spectrum.min.css', __FILE__ ), false, '2.0.8' );
        wp_register_style( 'tmfeed-main', plugins_url( '/css/main.css', __FILE__ ), false, '1.0' );
	}

	public function widget_scripts() {
		wp_register_script( 'spectrum', plugins_url( '/js/spectrum.min.js', __FILE__ ), [ 'jquery' ], false, true );
		wp_register_script( 'clipboard', plugins_url( '/js/clipboard.min.js', __FILE__ ), [ 'jquery' ], false, true );
        wp_register_script( 'tmfeed-list', plugins_url( '/js/list.js', __FILE__ ), [ 'jquery' ], false, true );
		wp_register_script( 'tmfeed-carousel', plugins_url( '/js/carousel.js', __FILE__ ), [ 'jquery' ], false, true );
		wp_register_script( 'tmfeed-newsticker', plugins_url( '/js/newsticker.js', __FILE__ ), [ 'jquery' ], false, true );
		wp_register_script( 'tmfeed-woo-slider', plugins_url( '/js/woo-slider.js', __FILE__ ), [ 'jquery' ], false, true );
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/list.php' );
		require_once( __DIR__ . '/widgets/carousel.php' );
		require_once( __DIR__ . '/widgets/newsticker.php' );
		require_once( __DIR__ . '/widgets/woo-slider.php' );
	}

	public function register_widgets() {
		$this->include_widgets_files();

		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TMfeed_List() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TMfeed_Carousel() );
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TMfeed_NewsTicker() );
		// Check WooCommerce Plugin
		if (class_exists( 'woocommerce' )) {
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\TMfeed_WooSlider() );
		}
	}

	public function widget_category($elements_manager) {
		$elements_manager->add_category(
			'tmfeed-widgets',
			[
				'title' => esc_html__( 'TMfeed', 'tmfeed' ),
				'icon' => 'fa fa-plug',
			]
		);
	}

	public function __construct() {
		add_action( 'elementor/frontend/after_enqueue_styles', [ $this, 'widget_styles' ] );
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );
		add_action( 'elementor/elements/categories_registered', [ $this, 'widget_category' ] );
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
}

TMfeedLoadElementor::instance();