<?php
namespace ElementorTMfeed\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

if ( ! defined( 'ABSPATH' ) ) exit;

class TMfeed_List extends Widget_Base {

	public function get_name() {
		return 'tmfeed-list';
	}

	public function get_title() {
		return esc_html__( 'TMfeed Post List', 'tmfeed' );
	}

	public function get_icon() {
		return 'eicon-post-list';
	}

	public function get_categories() {
		return [ 'tmfeed-widgets' ];
	}

    public function get_style_depends() {
		return [ 'spectrum','tmfeed-main' ];
	}
    
    public function get_script_depends() {
		return [ 'spectrum','clipboard','tmfeed-list' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'Settings', 'tmfeed' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        
        $this->add_control(
			'layout',
			[
				'label' => esc_html__( 'Widget Layout', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'row-reverse',
				'label_block' => 'true',
				'options' => [
                    'row'  => esc_html__( 'Row', 'tmfeed' ),
					'row-reverse'  => esc_html__( 'Row Reverse', 'tmfeed' ),
                    'column'  => esc_html__( 'Column', 'tmfeed' ),
					'column-reverse'  => esc_html__( 'Column Reverse', 'tmfeed' )
				],
			]
		);

        $this->add_responsive_control(
			'first_column_width',
			[
				'label' => esc_html__( 'Widget First Column Width (%)', 'tmfeed' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
                'default' => [
					'unit' => '%',
					'size' => 50,
				],
				'selectors' => [
					'{{WRAPPER}} .tmf-list-wrapper-row .tmf-list-left,{{WRAPPER}} .tmf-list-wrapper-row-reverse .tmf-list-left' => 'width: {{SIZE}}%;'
				],
                'conditions'   => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name'  => 'layout',
                            'value' => 'row',
                        ],
                        [
                            'name'  => 'layout',
                            'value' => 'row-reverse',
                        ]
                    ]
                ],
			]
		);

		$this->add_responsive_control(
			'second_column_width',
			[
				'label' => esc_html__( 'Widget Second Column Width (%)', 'tmfeed' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
                'default' => [
					'unit' => '%',
					'size' => 50,
				],
				'selectors' => [
                    '{{WRAPPER}} .tmf-list-wrapper-row .tmf-list-right,{{WRAPPER}} .tmf-list-wrapper-row-reverse .tmf-list-right' => 'width: {{SIZE}}%;'
				],
                'conditions'   => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name'  => 'layout',
                            'value' => 'row',
                        ],
                        [
                            'name'  => 'layout',
                            'value' => 'row-reverse',
                        ]
                    ]
                ],
			]
		);

		$this->add_control(
			'section_settings_hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_responsive_control(
			'columns',
			[
				'label' => esc_html__( 'Form Columns', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 6,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1,
				],
				'selectors' => [
                    '{{WRAPPER}} .tmf-form-wrapper' => 'grid-template-columns:repeat({{SIZE}}, 1fr);'
				],
			]
		);

		$this->add_responsive_control(
			'gap',
			[
				'label' => esc_html__( 'Form Grid Gap (px)', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 15,
				],
				'selectors' => [
                    '{{WRAPPER}} .tmf-form-wrapper' => 'grid-gap: {{SIZE}}{{UNIT}};'
				],
			]
		);

		$this->end_controls_section();

		// section start
		$this->start_controls_section(
			'defaults_section',
			[
				'label' => esc_html__( 'Default Values', 'tmfeed' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'tmf_title',
			[
				'label' => esc_html__( 'Title', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Recent Posts', 'tmfeed' ),
				'label_block' => true,
				'frontend_available' => true
			]
		);

		$this->add_control(
			'tmf_iframe_height',
			[
				'label' => esc_html__( 'Iframe Height (px)', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 50,
				'max' => 1000,
				'step' => 5,
				'default' => 350,
				'frontend_available' => true
			]
		);

		$this->add_control(
			'section_defaults_hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'tmf_post_tax',
			[
				'label' => esc_html__( 'Category', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => 'true',
				'frontend_available' => true,
				'options' => TMfeed_get_taxonomies('category')
			]
		);

		$this->add_control(
			'tmf_order',
			[
				'label' => esc_html__( 'Order', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'DESC',
				'label_block' => 'true',
				'frontend_available' => true,
				'options' => [
                    'DESC'  => esc_html__( 'Descending', 'tmfeed' ),
					'ASC'  => esc_html__( 'Ascending', 'tmfeed' )
				],
			]
		);
        
        $this->add_control(
			'tmf_orderby',
			[
				'label' => esc_html__( 'Order By', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'post_date',
				'label_block' => 'true',
				'frontend_available' => true,
				'options' => [
                    'post_date'  => esc_html__( 'Date', 'tmfeed' ),
					'title'  => esc_html__( 'Title', 'tmfeed' ),
					'rand'  => esc_html__( 'Random', 'tmfeed' ),
                    'comment_count'  => esc_html__( 'Comment Count', 'tmfeed' )
				],
			]
		);

		$this->add_control(
			'tmf_post_limit',
			[
				'label' => esc_html__( 'Post Limit', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => cmb2_get_option( 'tmfeed_options', 'tmf_post_limit', 10),
				'step' => 1,
				'default' => 5,
				'frontend_available' => true
			]
		);

		$this->add_control(
			'tmf_thumb',
			[
				'label' => esc_html__( 'Thumbnail', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'on',
				'frontend_available' => true,
				'options' => [
                    'on'  => esc_html__( 'Show', 'tmfeed' ),
					'off'  => esc_html__( 'Hide', 'tmfeed' )
				],
			]
		);

		$this->add_control(
			'tmf_author',
			[
				'label' => esc_html__( 'Author', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'on',
				'frontend_available' => true,
				'options' => [
                    'on'  => esc_html__( 'Show', 'tmfeed' ),
					'off'  => esc_html__( 'Hide', 'tmfeed' )
				],
			]
		);

		$this->add_control(
			'tmf_date',
			[
				'label' => esc_html__( 'Date', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'timeago',
				'frontend_available' => true,
				'options' => [
					'date'  => esc_html__( 'Default', 'tmfeed' ),
                    'timeago'  => esc_html__( 'Time ago', 'tmfeed' ),
					'hide'  => esc_html__( 'Hide', 'tmfeed' )
				],
			]
		);

		$this->add_control(
			'section_defaults_hr_2',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'tmf_font_family',
			[
				'label' => esc_html__( 'Font Family', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => 'true',
				'default' => 1,
				'options' => TMfeed_get_fonts(),
				'frontend_available' => true
			]
        );

		$this->add_control(
			'tmf_font_size',
			[
				'label' => esc_html__( 'Font Size (px)', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 999,
				'step' => 1,
				'default' => 16,
				'frontend_available' => true
			]
		);

		$this->add_control(
			'tmf_background',
			[
				'label' => esc_html__( 'Background', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'alpha' => false,
				'frontend_available' => true
			]
        );

		$this->add_control(
			'tmf_header_background',
			[
				'label' => esc_html__( 'Header Background', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#000000',
				'alpha' => false,
				'frontend_available' => true
			]
        );

		$this->add_control(
			'tmf_header_color',
			[
				'label' => esc_html__( 'Header Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ffffff',
				'alpha' => false,
				'frontend_available' => true
			]
        );

		$this->add_control(
			'tmf_border_color',
			[
				'label' => esc_html__( 'Border Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#DDDDDD',
				'alpha' => false,
				'frontend_available' => true
			]
        );

		$this->add_control(
			'tmf_link_color',
			[
				'label' => esc_html__( 'Link Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#000000',
				'alpha' => false,
				'frontend_available' => true
			]
        );

		$this->add_control(
			'tmf_text_color',
			[
				'label' => esc_html__( 'Text Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#444444',
				'alpha' => false,
				'frontend_available' => true
			]
        );

		$this->add_control(
			'section_defaults_hr_3',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'tmf_ref',
			[
				'label' => esc_html__( 'Referrer', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'iframe', 'tmfeed' ),
				'label_block' => true,
				'frontend_available' => true
			]
		);

		$this->end_controls_section();

		// section start
		$this->start_controls_section(
			'visibility_section',
			[
				'label' => esc_html__( 'Visibility', 'tmfeed' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'show_title',
			[
				'label' => esc_html__( 'Title', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_iframe_height',
			[
				'label' => esc_html__( 'Iframe Height', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'section_visibility_hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'show_category',
			[
				'label' => esc_html__( 'Category', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_order',
			[
				'label' => esc_html__( 'Order', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_orderby',
			[
				'label' => esc_html__( 'Order by', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_post_limit',
			[
				'label' => esc_html__( 'Post Limit', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_thumb',
			[
				'label' => esc_html__( 'Thumbnail', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_author',
			[
				'label' => esc_html__( 'Author', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_date',
			[
				'label' => esc_html__( 'Date', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'section_visibility_hr_2',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'show_font_family',
			[
				'label' => esc_html__( 'Font Family', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_font_size',
			[
				'label' => esc_html__( 'Font Size', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_background',
			[
				'label' => esc_html__( 'Background', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_header_background',
			[
				'label' => esc_html__( 'Header Background', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_header_color',
			[
				'label' => esc_html__( 'Header Color', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_border_color',
			[
				'label' => esc_html__( 'Border Color', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_link_color',
			[
				'label' => esc_html__( 'Link Color', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_text_color',
			[
				'label' => esc_html__( 'Text Color', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'section_visibility_hr_3',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'show_ref',
			[
				'label' => esc_html__( 'Referrer', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'section_visibility_hr_4',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'show_btn',
			[
				'label' => esc_html__( 'Button', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'tmfeed' ),
				'label_off' => esc_html__( 'Hide', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		// section start
		$this->start_controls_section(
			'labels_section',
			[
				'label' => esc_html__( 'Labels', 'tmfeed' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'tmf_title_label',
			[
				'label' => esc_html__( 'Title', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Title', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_iframe_height_label',
			[
				'label' => esc_html__( 'Iframe Height', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Iframe Height', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'section_labels_hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'tmf_category_label',
			[
				'label' => esc_html__( 'Category', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Category', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_order_label',
			[
				'label' => esc_html__( 'Order', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Order', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_orderby_label',
			[
				'label' => esc_html__( 'Order by', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Order by', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_post_limit_label',
			[
				'label' => esc_html__( 'Post Limit', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Post Limit', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_thumb_label',
			[
				'label' => esc_html__( 'Thumbnail', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Thumbnail', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_author_label',
			[
				'label' => esc_html__( 'Author', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Author', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_date_label',
			[
				'label' => esc_html__( 'Date', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Date', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'section_labels_hr_2',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'tmf_font_family_label',
			[
				'label' => esc_html__( 'Font Family', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Font Family', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_font_size_label',
			[
				'label' => esc_html__( 'Font Size', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Font Size', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_background_label',
			[
				'label' => esc_html__( 'Background', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Background', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_header_background_label',
			[
				'label' => esc_html__( 'Header Background', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Header Background', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_header_color_label',
			[
				'label' => esc_html__( 'Header Color', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Header Color', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_border_color_label',
			[
				'label' => esc_html__( 'Border Color', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Border Color', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_link_color_label',
			[
				'label' => esc_html__( 'Link Color', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Link Color', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_text_color_label',
			[
				'label' => esc_html__( 'Text Color', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Text Color', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_preview_label',
			[
				'label' => esc_html__( 'Preview', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Preview:', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'tmf_iframe_textbox_label',
			[
				'label' => esc_html__( 'Iframe Textbox', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Code to paste on your site:', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->add_control(
			'section_labels_hr_3',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'tmf_referrer_label',
			[
				'label' => esc_html__( 'Referrer', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Referrer', 'tmfeed' ),
				'label_block' => true
			]
		);

		$this->end_controls_section();

		// section start
		$this->start_controls_section(
			'btn_section',
			[
				'label' => esc_html__( 'Button', 'tmfeed' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        
        $this->add_control(
			'btn_text', [
				'label' => esc_html__( 'Text', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Copy to clipboard', 'tmfeed' ),
                'dynamic' => [
					'active' => true,
				],
			]
		);

		$this->add_control(
			'copied_text', [
				'label' => esc_html__( 'Copied Text', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( 'Copied!', 'tmfeed' ),
                'dynamic' => [
					'active' => true,
				],
			]
		);
        
        $this->add_control(
			'btn_size',
			[
				'label' => esc_html__( 'Size', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'tmf-btn-md',
				'options' => [
					'tmf-btn-md'  => esc_html__( 'Normal', 'tmfeed' ),
					'tmf-btn-lg'  => esc_html__( 'Large', 'tmfeed' ),
                    'tmf-btn-sm'  => esc_html__( 'Small', 'tmfeed' )
				],
			]
		);
        
        $this->add_responsive_control(
			'btn_text_align',
			[
				'label' => esc_html__( 'Alignment', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'tmfeed' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'tmfeed' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'tmfeed' ),
						'icon' => 'fa fa-align-right',
					]
				],
				'selectors' => [
					'{{WRAPPER}} .tmf-btn-wrapper' => 'text-align: {{VALUE}};'
				],
				'toggle' => true,
			]
		);
        
        $this->add_control(
			'btn_icon_hr_1',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);
        
        $this->add_control(
			'btn_icon_switcher',
			[
				'label' => esc_html__( 'Icon', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'tmfeed' ),
				'label_off' => esc_html__( 'No', 'tmfeed' ),
				'return_value' => 'yes',
				'default' => '',
			]
		);
        
        $this->add_control(
			'btn_icon',
			[
				'label' => esc_html__( 'Icon', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::ICONS,
                'show_label' => false,
                'condition' => ['btn_icon_switcher' => 'yes'],
			]
		);
        
        $this->add_control(
			'btn_icon_position',
			[
				'label' => esc_html__( 'Icon Position', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'before',
				'options' => [
					'after'  => esc_html__( 'After', 'tmfeed' ),
					'before'  => esc_html__( 'Before', 'tmfeed' )
				],
                'condition' => ['btn_icon_switcher' => 'yes'],
			]
		);
        
        $this->add_responsive_control(
			'btn_icon_spacing',
			[
				'label' => esc_html__( 'Icon Padding', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-btn-wrapper a i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
                'condition' => ['btn_icon_switcher' => 'yes'],
			]
		);
       
		$this->end_controls_section();
		
		// section start
		$this->start_controls_section(
			'section_form_container_style',
			[
				'label' => esc_html__( 'Form Container', 'tmfeed' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'form_container_bg',
				'label' => esc_html__( 'Background', 'tmfeed' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .tmf-list-left',
			]
		);

		$this->add_control(
			'form_container_hr',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'form_container_border',
				'label' => esc_html__( 'Border', 'tmfeed' ),
				'selector' => '{{WRAPPER}} .tmf-list-left'
			]
		);
        
        $this->add_responsive_control(
			'form_container_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .tmf-list-left' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'form_container_shadow',
				'label' => esc_html__( 'Box Shadow', 'tmfeed' ),
				'selector' => '{{WRAPPER}} .tmf-list-left'
			]
		);

		$this->add_control(
			'form_container_hr_2',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);
        
        $this->add_responsive_control(
			'form_container_padding',
			[
				'label' => esc_html__( 'Padding', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-list-left' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);

		$this->end_controls_section();
		
		// section start
		$this->start_controls_section(
			'section_form_labels_style',
			[
				'label' => esc_html__( 'Form Labels', 'tmfeed' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			'label_color',
			[
				'label' => esc_html__( 'Text Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
				'selectors' => [
					'{{WRAPPER}} .tmf-list-left .tmf-input-label' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'label_typography',
				'selector' => '{{WRAPPER}} .tmf-list-left .tmf-input-label',
			]
		);

		$this->add_responsive_control(
			'label_align',
			[
				'label' => esc_html__( 'Text Align', 'tmfeed' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'tmfeed' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'tmfeed' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'tmfeed' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .tmf-list-left .tmf-input-label' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'label_hr',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);

		$this->add_responsive_control(
			'label_margin',
			[
				'label' => esc_html__( 'Margin', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-list-left .tmf-input-label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);
        
        $this->add_responsive_control(
			'label_padding',
			[
				'label' => esc_html__( 'Padding', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-list-left .tmf-input-label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);

		$this->end_controls_section();

		 // section start
		 $this->start_controls_section(
			'section_input_style',
			[
				'label' => esc_html__( 'Form Fields', 'tmfeed' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'input_typography',		
				'selector' => '{{WRAPPER}} input[type="text"].tmf-input-text,{{WRAPPER}} input[type="number"].tmf-input-text,{{WRAPPER}} input[type="text"].tmf-colorpicker,{{WRAPPER}} select.tmf-select'
			]
		);
        
        $this->add_control(
			'input_hr_1',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		); 
        
        $this->start_controls_tabs( 'form_input_style' );
        
        $this->start_controls_tab(
			'form_input_normal',
			[
				'label' => esc_html__( 'Normal', 'tmfeed' ),
			]
		);
        
        $this->add_control(
			'text_color',
			[
				'label' => esc_html__( 'Text Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} input[type="text"].tmf-input-text' => 'color: {{VALUE}};',
					'{{WRAPPER}} input[type="number"].tmf-input-text' => 'color: {{VALUE}};',
					'{{WRAPPER}} input[type="text"].tmf-colorpicker' => 'color: {{VALUE}};',
					'{{WRAPPER}} select.tmf-select' => 'color: {{VALUE}};',
				]
			]
		);
        
        $this->add_control(
			'bg_color',
			[
				'label' => esc_html__( 'Background Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} input[type="text"].tmf-input-text' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} input[type="number"].tmf-input-text' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} input[type="text"].tmf-colorpicker' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} select.tmf-select' => 'background-color: {{VALUE}};',
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => esc_html__( 'Border', 'tmfeed' ),
				'selector' => '{{WRAPPER}} input[type="text"].tmf-input-text,{{WRAPPER}} input[type="number"].tmf-input-text,{{WRAPPER}} input[type="text"].tmf-colorpicker,{{WRAPPER}} select.tmf-select'
			]
		);
        
        $this->add_responsive_control(
			'border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} input[type="text"].tmf-input-text' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} input[type="number"].tmf-input-text' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} input[type="text"].tmf-colorpicker' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} select.tmf-select' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'border_shadow',
				'label' => esc_html__( 'Box Shadow', 'tmfeed' ),
				'selector' => '{{WRAPPER}} input[type="text"].tmf-input-text,{{WRAPPER}} input[type="number"].tmf-input-text,{{WRAPPER}} input[type="text"].tmf-colorpicker,{{WRAPPER}} select.tmf-select'
			]
		);
        
        $this->end_controls_tab();

		$this->start_controls_tab(
			'form_input_hover',
			[
				'label' => esc_html__( 'Focus', 'tmfeed' ),
			]
		);
        
        $this->add_control(
			'text_hover_color',
			[
				'label' => esc_html__( 'Text Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
				'selectors' => [
					'{{WRAPPER}} input[type="text"].tmf-input-text:focus' => 'color: {{VALUE}};',
					'{{WRAPPER}} input[type="number"].tmf-input-text:focus' => 'color: {{VALUE}};',
					'{{WRAPPER}} input[type="text"].tmf-colorpicker:focus' => 'color: {{VALUE}};'
				]
			]
		);
        
        $this->add_control(
			'bg_hover_color',
			[
				'label' => esc_html__( 'Background Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
				'selectors' => [
					'{{WRAPPER}} input[type="text"].tmf-input-text:focus' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} input[type="number"].tmf-input-text:focus' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} input[type="text"].tmf-colorpicker:focus' => 'background-color: {{VALUE}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'hover_border',
				'label' => esc_html__( 'Border', 'tmfeed' ),
				'selector' => '{{WRAPPER}} input[type="text"].tmf-input-text:focus,{{WRAPPER}} input[type="number"].tmf-input-text:focus,{{WRAPPER}} input[type="text"].tmf-colorpicker:focus'
			]
		);
        
        $this->add_responsive_control(
			'border_hover_radius',
			[
				'label' => esc_html__( 'Border Radius', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} input[type="text"].tmf-input-text:focus' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} input[type="number"].tmf-input-text:focus' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} input[type="text"].tmf-colorpicker:focus' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} select.tmf-select:focus' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'border_hover_shadow',
				'label' => esc_html__( 'Box Shadow', 'tmfeed' ),
				'selector' => '{{WRAPPER}} input[type="text"].tmf-input-text:focus,{{WRAPPER}} input[type="number"].tmf-input-text:focus,{{WRAPPER}} input[type="text"].tmf-colorpicker:focus'
			]
		);
        
        $this->end_controls_tab();
        $this->end_controls_tabs();
        
        $this->add_control(
			'input_hr_2',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_responsive_control(
			'input_height',
			[
				'label' => esc_html__( 'Height (px)', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 10,
				'max' => 100,
				'step' => 1,
                'default' => 40,
                'selectors' => [
					'{{WRAPPER}} input[type="text"].tmf-input-text' => 'height: {{VALUE}}px;',
					'{{WRAPPER}} input[type="number"].tmf-input-text' => 'height: {{VALUE}}px;',
					'{{WRAPPER}} input[type="text"].tmf-colorpicker' => 'height: {{VALUE}}px;',
					'{{WRAPPER}} select.tmf-select' => 'height: {{VALUE}}px;'
				],
			]
		);
        
        $this->add_responsive_control(
			'input_padding',
			[
				'label' => esc_html__( 'Padding', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} input[type="text"].tmf-input-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} input[type="number"].tmf-input-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} input[type="text"].tmf-colorpicker' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} select.tmf-select' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        
        $this->add_responsive_control(
			'input_margin',
			[
				'label' => esc_html__( 'Margin', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} input[type="text"].tmf-input-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} input[type="number"].tmf-input-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} input[type="text"].tmf-colorpicker' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} select.tmf-select' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        
        $this->end_controls_section();
		
		// section start
		$this->start_controls_section(
			'section_iframe_container_style',
			[
				'label' => esc_html__( 'Iframe Container', 'tmfeed' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'iframe_container_bg',
				'label' => esc_html__( 'Background', 'tmfeed' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .tmf-list-right',
			]
		);

		$this->add_control(
			'iframe_container_hr',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iframe_container_border',
				'label' => esc_html__( 'Border', 'tmfeed' ),
				'selector' => '{{WRAPPER}} .tmf-list-right'
			]
		);
        
        $this->add_responsive_control(
			'iframe_container_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .tmf-list-right' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'iframe_container_shadow',
				'label' => esc_html__( 'Box Shadow', 'tmfeed' ),
				'selector' => '{{WRAPPER}} .tmf-list-right'
			]
		);

		$this->add_control(
			'iframe_container_hr_2',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);

		$this->add_responsive_control(
			'iframe_container_spacing',
			[
				'label' => esc_html__( 'Box Spacing (px)', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 999,
				'step' => 1,
				'default' => 30,
				'selectors' => [
                    '{{WRAPPER}} .tmf-iframe-output' => 'margin-top: {{SIZE}}px;'
				],
			]
		);
        
        $this->add_responsive_control(
			'iframe_container_padding',
			[
				'label' => esc_html__( 'Padding', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-list-right' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);

		$this->end_controls_section();
		
		// section start
		$this->start_controls_section(
			'section_iframe_style',
			[
				'label' => esc_html__( 'Iframe', 'tmfeed' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'iframe_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
				'selectors' => [
					'{{WRAPPER}} .tmf-list-right iframe' => 'background-color: {{VALUE}};'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'iframe_border',
				'label' => esc_html__( 'Border', 'tmfeed' ),
				'selector' => '{{WRAPPER}} .tmf-list-right iframe'
			]
		);
        
        $this->add_responsive_control(
			'iframe_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .tmf-list-right iframe' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'iframe_shadow',
				'label' => esc_html__( 'Box Shadow', 'tmfeed' ),
				'selector' => '{{WRAPPER}} .tmf-list-right iframe'
			]
		);

		$this->add_control(
			'iframe_hr',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);
        
        $this->add_responsive_control(
			'iframe_padding',
			[
				'label' => esc_html__( 'Padding', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-list-right iframe' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);
        
        $this->end_controls_section();

		// section start
		$this->start_controls_section(
			'section_iframe_labels_style',
			[
				'label' => esc_html__( 'Iframe Labels', 'tmfeed' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'iframe_label_color',
			[
				'label' => esc_html__( 'Text Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
				'selectors' => [
					'{{WRAPPER}} .tmf-list-right .tmf-input-label' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'iframe_label_typography',
				'selector' => '{{WRAPPER}} .tmf-list-right .tmf-input-label',
			]
		);

		$this->add_responsive_control(
			'iframe_label_align',
			[
				'label' => esc_html__( 'Text Align', 'tmfeed' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'tmfeed' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'tmfeed' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'tmfeed' ),
						'icon' => 'eicon-text-align-right',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .tmf-list-right .tmf-input-label' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'iframe_label_hr',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);

		$this->add_responsive_control(
			'iframe_label_margin',
			[
				'label' => esc_html__( 'Margin', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-list-right .tmf-input-label' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);
        
        $this->add_responsive_control(
			'iframe_label_padding',
			[
				'label' => esc_html__( 'Padding', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-list-right .tmf-input-label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);

		$this->end_controls_section();

		// section start
		$this->start_controls_section(
			'section_code_box_style',
			[
				'label' => esc_html__( 'Code Box', 'tmfeed' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'code_typography',		
				'selector' => '{{WRAPPER}} textarea.tmf-textarea'
			]
		);
        
        $this->add_control(
			'code_hr_1',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		); 
        
        $this->start_controls_tabs( 'form_code_style' );
        
        $this->start_controls_tab(
			'form_code_normal',
			[
				'label' => esc_html__( 'Normal', 'tmfeed' ),
			]
		);
        
        $this->add_control(
			'code_text_color',
			[
				'label' => esc_html__( 'Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} textarea.tmf-textarea' => 'color: {{VALUE}};'
				]
			]
		);
        
        $this->add_control(
			'code_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} textarea.tmf-textarea' => 'background-color: {{VALUE}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'code_border',
				'label' => esc_html__( 'Border', 'tmfeed' ),
				'selector' => '{{WRAPPER}} textarea.tmf-textarea'
			]
		);
        
        $this->add_responsive_control(
			'code_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} textarea.tmf-textarea' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'code_border_shadow',
				'label' => esc_html__( 'Box Shadow', 'tmfeed' ),
				'selector' => '{{WRAPPER}} textarea.tmf-textarea'
			]
		);
        
        $this->end_controls_tab();

		$this->start_controls_tab(
			'form_code_hover',
			[
				'label' => esc_html__( 'Focus', 'tmfeed' ),
			]
		);
        
        $this->add_control(
			'code_hover_color',
			[
				'label' => esc_html__( 'Text Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
				'selectors' => [
					'{{WRAPPER}} textarea.tmf-textarea:focus' => 'color: {{VALUE}};'
				]
			]
		);
        
        $this->add_control(
			'code_bg_hover_color',
			[
				'label' => esc_html__( 'Background Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
				'selectors' => [
					'{{WRAPPER}} textarea.tmf-textarea:focus' => 'background-color: {{VALUE}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'code_hover_border',
				'label' => esc_html__( 'Border', 'tmfeed' ),
				'selector' => '{{WRAPPER}} textarea.tmf-textarea:focus'
			]
		);
        
        $this->add_responsive_control(
			'code_border_hover_radius',
			[
				'label' => esc_html__( 'Border Radius', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} textarea.tmf-textarea:focus' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'code_border_hover_shadow',
				'label' => esc_html__( 'Box Shadow', 'tmfeed' ),
				'selector' => '{{WRAPPER}} textarea.tmf-textarea:focus'
			]
		);
        
        $this->end_controls_tab();
        $this->end_controls_tabs();
        
        $this->add_control(
			'code_hr_2',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_responsive_control(
			'code_height',
			[
				'label' => esc_html__( 'Height', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 5,
				'max' => 100,
				'step' => 1,
                'default' => 10
			]
		);
        
        $this->add_responsive_control(
			'code_padding',
			[
				'label' => esc_html__( 'Padding', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} textarea.tmf-textarea' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);
        
        $this->add_responsive_control(
			'code_margin',
			[
				'label' => esc_html__( 'Margin', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} textarea.tmf-textarea' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);

		$this->end_controls_section();

		// section start
		$this->start_controls_section(
			'section_btn_style',
			[
				'label' => esc_html__( 'Button', 'tmfeed' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'btn_typography',
				'selector' => '{{WRAPPER}} .tmf-btn-wrapper a',
			]
		);

		$this->add_control(
			'btn_skin',
			[
				'label' => esc_html__( 'Animation', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => TMfeed_btn_anims()
			]
		);
        
        $this->add_control(
			'btn_hr_1',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);  
        
        $this->start_controls_tabs( 'tabs_button_style' );
        
        $this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => esc_html__( 'Normal', 'tmfeed' ),
			]
		);
        
        $this->add_control(
			'btn_text_color',
			[
				'label' => esc_html__( 'Text Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
                'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .tmf-btn-wrapper a' => 'color: {{VALUE}};',
				]
			]
		);
        
        $this->add_control(
			'btn_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR,
                'default' => '#000000',
				'selectors' => [
					'{{WRAPPER}} .tmf-btn-wrapper a' => 'background-color: {{VALUE}};',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'btn_bg_color_gradient',
				'label' => esc_html__( 'Background', 'tmfeed' ),
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .tmf-btn-wrapper a',
			]
		);
        
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'btn_border',
				'label' => esc_html__( 'Border', 'tmfeed' ),
				'selector' => '{{WRAPPER}} .tmf-btn-wrapper a'
			]
		);
        
        $this->add_responsive_control(
			'btn_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .tmf-btn-wrapper a,{{WRAPPER}} .tmf-btn-wrapper a:before' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'btn_border_shadow',
				'label' => esc_html__( 'Box Shadow', 'tmfeed' ),
				'selector' => '{{WRAPPER}} .tmf-btn-wrapper a'
			]
		);

		$this->add_responsive_control(
			'btn_padding',
			[
				'label' => esc_html__( 'Padding', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-btn-wrapper a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);

		$this->add_responsive_control(
			'btn_margin',
			[
				'label' => esc_html__( 'Margin', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-btn-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);
        
        $this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => esc_html__( 'Hover', 'tmfeed' ),
			]
		);
        
        $this->add_control(
			'btn_text_hover_color',
			[
				'label' => esc_html__( 'Text Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
				'selectors' => [
					'{{WRAPPER}} .tmf-btn-wrapper a:hover' => 'color: {{VALUE}};'
				]
			]
		);
        
        $this->add_control(
			'btn_bg_hover_color',
			[
				'label' => esc_html__( 'Background Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
				'selectors' => [
					'{{WRAPPER}} .tmf-btn-wrapper a:hover' => 'background-color: {{VALUE}};'
				]
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'btn_bg_color_hover_gradient',
				'label' => esc_html__( 'Background', 'tmfeed' ),
				'types' => [ 'gradient' ],
				'selector' => '{{WRAPPER}} .tmf-btn-wrapper a:hover',
			]
		);
        
        $this->add_control(
			'btn_animation_color',
			[
				'label' => esc_html__( 'Animation Color', 'tmfeed' ),
				'type' => Controls_Manager::COLOR, 
				'selectors' => [
					'{{WRAPPER}} .tmf-btn-wrapper a:before' => 'background-color: {{VALUE}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'btn_hover_border',
				'label' => esc_html__( 'Border', 'tmfeed' ),
				'selector' => '{{WRAPPER}} .tmf-btn-wrapper a:hover'
			]
		);
        
        $this->add_responsive_control(
			'btn_border_hover_radius',
			[
				'label' => esc_html__( 'Border Radius', 'tmfeed' ),
				'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .tmf-btn-wrapper a:hover,{{WRAPPER}} .tmf-btn-wrapper a:hover:before' => 'border-top-left-radius: {{TOP}}{{UNIT}};border-top-right-radius: {{RIGHT}}{{UNIT}};border-bottom-right-radius: {{BOTTOM}}{{UNIT}};border-bottom-left-radius: {{LEFT}}{{UNIT}};'
				]
			]
		);
        
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'btn_border_hover_shadow',
				'label' => esc_html__( 'Box Shadow', 'tmfeed' ),
				'selector' => '{{WRAPPER}} .tmf-btn-wrapper a:hover'
			]
		);

		$this->add_responsive_control(
			'btn_padding_hover',
			[
				'label' => esc_html__( 'Padding', 'tmfeed' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
                    '{{WRAPPER}} .tmf-btn-wrapper a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
				],
			]
		);
        
        $this->end_controls_tab();
        $this->end_controls_tabs();
        
        $this->add_control(
			'btn_hr_2',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		); 
        
        $this->add_responsive_control(
			'btn_width',
			[
				'label' => esc_html__( 'Button Width', 'tmfeed' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem' ],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
                    'px' => [
						'min' => 0,
						'max' => 1000,
					],
                    'rem' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .tmf-btn-wrapper a' => 'width: {{SIZE}}{{UNIT}};'
				],
			]
		);
        
        $this->end_controls_section();
	}
    
    protected function render() {
		$settings = $this->get_settings_for_display();
		$widget_id = $this->get_id();
		$iframe_height = $settings['tmf_iframe_height'] ? $settings['tmf_iframe_height'] : 350;
		$post_limit = cmb2_get_option( 'tmfeed_options', 'tmf_post_limit', 10);
		$parameters = array(
			'tmf_title' => $settings['tmf_title'] ? $settings['tmf_title'] : '',
			'tmf_post_tax' => $settings['tmf_post_tax'] ? $settings['tmf_post_tax'] : 0,
			'tmf_order' => $settings['tmf_order'] ? $settings['tmf_order'] : 'DESC',
			'tmf_orderby' => $settings['tmf_orderby'] ? $settings['tmf_orderby'] : 'post_date',
			'tmf_post_limit' => $settings['tmf_post_limit'] && $settings['tmf_post_limit'] <= $post_limit ? $settings['tmf_post_limit'] : $post_limit,
			'tmf_thumb' => $settings['tmf_thumb'] ? $settings['tmf_thumb'] : 1,
			'tmf_author' => $settings['tmf_author'] ? $settings['tmf_author'] : 1,
			'tmf_date' => $settings['tmf_date'] ? $settings['tmf_date'] : 'timeago',
			'tmf_font_family' => $settings['tmf_font_family'] ? $settings['tmf_font_family'] : 1,
			'tmf_font_size' => $settings['tmf_font_size'] ? $settings['tmf_font_size'] : 16,
			'tmf_background' => $settings['tmf_background'] ? $settings['tmf_background'] : '#ffffff',
			'tmf_header_background' => $settings['tmf_header_background'] ? $settings['tmf_header_background'] : '#000000',
			'tmf_header_color' => $settings['tmf_header_color'] ? $settings['tmf_header_color'] : '#ffffff',
			'tmf_border_color' => $settings['tmf_border_color'] ? $settings['tmf_border_color'] : '#DDDDDD',
			'tmf_link_color' => $settings['tmf_link_color'] ? $settings['tmf_link_color'] : '#000000',
			'tmf_text_color' => $settings['tmf_text_color'] ? $settings['tmf_text_color'] : '#444444',
			'tmf_ref' => $settings['tmf_ref'] ? $settings['tmf_ref'] : 'iframe',
		);
		$output_parameters = '';
		foreach($parameters as $key => $parameter) {
			$output_parameters != "" && $output_parameters .= "&amp;";
			$output_parameters .= $key . '=' . str_replace('#', '', $parameter);
		}
        ?>
        <div class="tmf-list-wrapper tmf-list-wrapper-<?php echo esc_attr($settings['layout']); ?>">
            <div class="tmf-list-left">
					<form id="tmf-list-form-<?php echo esc_attr($widget_id); ?>" class="tmf-form-wrapper" action="<?php the_permalink(); ?>">
					<?php if ( 'yes' === $settings['show_title'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_title_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_title_label']); ?></label>
							<?php } ?>
							<input class="tmf-input-text" type="text" id="tmf_title" name="tmf_title" value="<?php echo esc_attr($parameters['tmf_title']); ?>" autocomplete="off">
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_iframe_height'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_iframe_height_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_iframe_height_label']); ?></label>
							<?php } ?>
							<input class="tmf-input-text tmf-numeric" type="number" id="tmf_iframe_height" name="tmf_iframe_height" value="<?php echo esc_attr($iframe_height); ?>" autocomplete="off" required>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_category'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_category_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_category_label']); ?></label>
							<?php } ?>
							<select class="tmf-select" id="tmf_post_tax" name="tmf_post_tax" autocomplete="off">
							<?php 
							$font_cat_array = TMfeed_get_taxonomies('category'); 
							foreach($font_cat_array as $key => $item) {
								$selected = '';
								if ($key == $parameters['tmf_post_tax']) {
									$selected = 'selected';
								}
								echo '<option value="' . esc_attr($key) . '" ' . esc_attr($selected) . '>' . esc_html($item) . '</option>';
							}
							?>
							</select>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_order'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_order_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_order_label']); ?></label>
							<?php } ?>
							<select class="tmf-select" id="tmf_order" name="tmf_order" autocomplete="off">
								<option value="DESC" <?php if($parameters['tmf_order'] == 'DESC') { echo 'selected'; } ?>><?php echo esc_html__( 'Descending', 'tmfeed' ); ?></option>
								<option value="ASC" <?php if($parameters['tmf_order'] == 'ASC') { echo 'selected'; } ?>><?php echo esc_html__( 'Ascending', 'tmfeed' ); ?></option>
							</select>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_orderby'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_orderby_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_orderby_label']); ?></label>
							<?php } ?>
							<select class="tmf-select" id="tmf_orderby" name="tmf_order" autocomplete="off">
								<option value="post_date" <?php if($parameters['tmf_orderby'] == 'post_date') { echo 'selected'; } ?>><?php echo esc_html__( 'Date', 'tmfeed' ); ?></option>
								<option value="title" <?php if($parameters['tmf_orderby'] == 'title') { echo 'selected'; } ?>><?php echo esc_html__( 'Title', 'tmfeed' ); ?></option>
								<option value="rand" <?php if($parameters['tmf_orderby'] == 'rand') { echo 'selected'; } ?>><?php echo esc_html__( 'Random', 'tmfeed' ); ?></option>
								<option value="comment_count" <?php if($parameters['tmf_orderby'] == 'comment_count') { echo 'selected'; } ?>><?php echo esc_html__( 'Comment Count', 'tmfeed' ); ?></option>
							</select>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_post_limit'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_post_limit_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_post_limit_label']); ?></label>
							<?php } ?>
							<input class="tmf-input-text tmf-numeric" type="number" id="tmf_post_limit" name="tmf_post_limit" value="<?php echo esc_attr($parameters['tmf_post_limit']); ?>" autocomplete="off" min="1" max="<?php echo esc_attr($post_limit); ?>" required>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_thumb'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_thumb_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_thumb_label']); ?></label>
							<?php } ?>
							<select class="tmf-select" id="tmf_thumb" name="tmf_thumb" autocomplete="off">
								<option value="on" <?php if($parameters['tmf_thumb'] == 'on') { echo 'selected'; } ?>><?php echo esc_html__( 'Show', 'tmfeed' ); ?></option>
								<option value="off" <?php if($parameters['tmf_thumb'] == 'off') { echo 'selected'; } ?>><?php echo esc_html__( 'Hide', 'tmfeed' ); ?></option>
							</select>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_author'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_author_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_author_label']); ?></label>
							<?php } ?>
							<select class="tmf-select" id="tmf_author" name="tmf_author" autocomplete="off">
								<option value="on" <?php if($parameters['tmf_author'] == 'on') { echo 'selected'; } ?>><?php echo esc_html__( 'Show', 'tmfeed' ); ?></option>
								<option value="off" <?php if($parameters['tmf_author'] == 'off') { echo 'selected'; } ?>><?php echo esc_html__( 'Hide', 'tmfeed' ); ?></option>
							</select>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_date'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_date_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_date_label']); ?></label>
							<?php } ?>
							<select class="tmf-select" id="tmf_date" name="tmf_date" autocomplete="off">
								<option value="date" <?php if($parameters['tmf_date'] == 'date') { echo 'selected'; } ?>><?php echo esc_html__( 'Default', 'tmfeed' ); ?></option>
								<option value="timeago" <?php if($parameters['tmf_date'] == 'timeago') { echo 'selected'; } ?>><?php echo esc_html__( 'Time ago', 'tmfeed' ); ?></option>
								<option value="hide" <?php if($parameters['tmf_date'] == 'hide') { echo 'selected'; } ?>><?php echo esc_html__( 'Hide', 'tmfeed' ); ?></option>
							</select>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_font_family'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_font_family_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_font_family_label']); ?></label>
							<?php } ?>
							<select class="tmf-select" id="tmf_font_family" name="tmf_font_family" autocomplete="off">
							<?php 
							$font_family_array = TMfeed_get_fonts(); 
							foreach($font_family_array as $key => $item) {
								$selected = '';
								if ($key == $parameters['tmf_font_family']) {
									$selected = 'selected';
								}
								echo '<option value="' . esc_attr($key) . '" ' . esc_attr($selected) . '>' . esc_html($item) . '</option>';
							}
							?>
							</select>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_font_size'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_font_size_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_font_size_label']); ?></label>
							<?php } ?>
							<input class="tmf-input-text tmf-numeric" type="number" id="tmf_font_size" name="tmf_font_size" value="<?php echo esc_attr($parameters['tmf_font_size']); ?>" autocomplete="off" min="1" max="50" required>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_background'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_background_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_background_label']); ?></label>
							<?php } ?>
							<input class="tmf-colorpicker basic" type="text" id="tmf_background" name="tmf_background" value="<?php echo esc_attr($parameters['tmf_background']); ?>" autocomplete="off" required>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_header_background'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_header_background_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_header_background_label']); ?></label>
							<?php } ?>
							<input class="tmf-colorpicker basic" type="text" id="tmf_header_background" name="tmf_header_background" value="<?php echo esc_attr($parameters['tmf_header_background']); ?>" autocomplete="off" required>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_header_color'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_header_color_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_header_color_label']); ?></label>
							<?php } ?>
							<input class="tmf-colorpicker basic" type="text" id="tmf_header_color" name="tmf_header_color" value="<?php echo esc_attr($parameters['tmf_header_color']); ?>" autocomplete="off" required>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_border_color'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_border_color_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_border_color_label']); ?></label>
							<?php } ?>
							<input class="tmf-colorpicker basic" type="text" id="tmf_border_color" name="tmf_border_color" value="<?php echo esc_attr($parameters['tmf_border_color']); ?>" autocomplete="off" required>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_link_color'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_link_color_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_link_color_label']); ?></label>
							<?php } ?>
							<input class="tmf-colorpicker basic" type="text" id="tmf_link_color" name="tmf_link_color" value="<?php echo esc_attr($parameters['tmf_link_color']); ?>" autocomplete="off" required>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_text_color'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_text_color_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_text_color_label']); ?></label>
							<?php } ?>
							<input class="tmf-colorpicker basic" type="text" id="tmf_text_color" name="tmf_text_color" value="<?php echo esc_attr($parameters['tmf_text_color']); ?>" autocomplete="off" required>
						</div>
					<?php } ?>
					<?php if ( 'yes' === $settings['show_ref'] ) { ?>
						<div class="tmf-form-field">
							<?php if ($settings['tmf_referrer_label']) { ?>
							<label class="tmf-input-label"><?php echo esc_html($settings['tmf_referrer_label']); ?></label>
							<?php } ?>
							<input class="tmf-input-text tmf-ref" type="text" id="tmf_ref" name="tmf_ref" value="<?php echo esc_attr($parameters['tmf_ref']); ?>" autocomplete="off" required>
						</div>
					<?php } ?>
					</form>
                </div>
            <div class="tmf-list-right">
				<?php if ($settings['tmf_preview_label']) { ?>
				<label class="tmf-input-label"><?php echo esc_html($settings['tmf_preview_label']); ?></label>
				<?php } ?>
				<iframe id="tmf-list-iframe-<?php echo esc_attr($widget_id); ?>" scrolling="yes" src="<?php echo esc_url(home_url( '/' ) . '?tmf_embed=post_list&' . $output_parameters); ?>" width="100%" height="<?php echo esc_attr($iframe_height); ?>px" frameborder="0"></iframe>
				<div class="tmf-form-field tmf-iframe-output">
					<?php if ($settings['tmf_iframe_textbox_label']) { ?>
					<label class="tmf-input-label"><?php echo esc_html($settings['tmf_iframe_textbox_label']); ?></label>
					<?php } ?>
					<textarea id="tmf-iframe-output-<?php echo esc_attr($widget_id); ?>" class="tmf-textarea" name="tmf-iframe-output-<?php echo esc_attr($widget_id); ?>" data-home="<?php echo esc_url(home_url( '/' )); ?>" class="tmf-textarea tmf-iframe-output" rows="<?php echo esc_attr($settings['code_height']); ?>" autocomplete="off" readonly><iframe scrolling="yes" src="<?php echo esc_url(home_url( '/' ) . '?tmf_embed=post_list&' . $output_parameters); ?>" width="100%" height="<?php echo esc_attr($iframe_height); ?>px" frameborder="0"></iframe></textarea>
				</div>
				<?php if ( 'yes' === $settings['show_btn'] ) { ?>
					<div class="tmf-btn-wrapper">
						<a href="#" class="tmf-clipboard-btn <?php echo esc_attr($settings['btn_size'] . ' ' . $settings['btn_skin']); ?>" data-clipboard-target="#tmf-iframe-output-<?php echo esc_attr($widget_id); ?>" data-copied="<?php echo esc_attr($settings['copied_text']); ?>">
							<?php 
							if ($settings['btn_icon_switcher']) {
								if ($settings['btn_icon_position'] == 'before') {
									\Elementor\Icons_Manager::render_icon( $settings['btn_icon'], [ 'aria-hidden' => 'true' ] );
									echo '<span>' . esc_html($settings['btn_text']) . '</span>';
								} else {
									echo '<span>' . esc_html($settings['btn_text']) . '</span>'; 
									\Elementor\Icons_Manager::render_icon( $settings['btn_icon'], [ 'aria-hidden' => 'true' ] );
								}
							} else {
								echo '<span>' . esc_html($settings['btn_text']) . '</span>';
							} 
							?>
						</a>
					</div>
				<?php } ?>
            </div>
        </div>
<?php
    }
}
?>